## DESCRIPTION

*r.spread* is part of the wildfire simulation toolset. Preparational
steps for the fire simulation are the calculation of the rate of spread
(ROS) with *r.ros*, and the creating of spread map with *r.spread*.
Eventually, the fire path(s) based on starting point(s) are calculated
with *r.spreadpath*.

Spread phenomena usually show uneven movement over space. Such
unevenness is due to two reasons:

1. the uneven conditions from location to location, which can be called
    *spatial heterogeneity*, and
2. the uneven conditions in different directions, which can be called
    *anisotropy*.

The anisotropy of spread occurs when any of the determining factors have
directional components. For example, wind and topography cause
anisotropic spread of wildfires.

One of the simplest spatial heterogeneous and anisotropic spread is
elliptical spread, in which, each local spread shape can be thought as
an ellipse. In a raster setting, cell centers are foci of the spread
ellipses, and the spread phenomenon moves fastest toward apogees and
slowest to perigees. The sizes and shapes of spread ellipses may vary
cell by cell. So the overall spread shape is commonly not an ellipse.

*r.spread*simulates elliptically anisotropic spread phenomena, given
three raster map layers about ROS (base ROS, maximum ROS and direction
of the maximum ROS) plus a raster map layer showing the starting
sources. These ROS layers define unique ellipses for all cell locations
in the current computational region as if each cell center was a
potential spread origin. For some wildfire spread, these ROS layers can
be generated by another GRASS raster program r.ros. The actual locations
reached by a spread event are constrained by the actual spread origins
and the elapsed spread time.

*r.spread*optionally produces raster maps to contain backlink UTM
coordinates for each raster cell of the spread time map. The spread
paths can be accurately traced based on the backlink information by
*[r.spreadpath](r.spreadpath.md)* module.

Part of the spotting function in r.spread is based on Chase (1984) and
Rothermel (1983). More information on *r.spread*, *[r.ros](r.ros.md)*
and *[r.spreadpath](r.spreadpath.md)* can be found in Xu (1994).

Options `spot_dist`, `w_speed` and `f_mois` must all be given if the
`-s` (spotting) flag is used.

## EXAMPLE

Assume we have inputs, the following simulates a spotting- involved
wildfire and generates three raster maps to contain spread time,
backlink information in UTM northing and easting coordinates:

```sh
r.spread -s max=my_ros.max dir=my_ros.maxdir base=my_ros.base \
    start=fire_origin spot_dist=my_ros.spotdist w_speed=wind_speed \
    f_mois=1hour_moisture output=my_spread \
    x_output=my_spread.x y_output=my_spread.y
```

## NOTES

1\. *r.spread* is a specific implementation of the shortest path
algorithm. *[r.cost](r.cost.md)* module served as the starting point for
the development of *r.spread*. One of the major differences between the
two programs is that *[r.cost](r.cost.md)* only simulates *isotropic*
spread while *r.spread* can simulate *elliptically anisotropic* spread,
including isotropic spread as a special case.

2\. Before running r.spread, the user should prepare the ROS (base, max
and direction) maps using appropriate models. For some wildfire spread,
the *[r.ros](r.ros.md)* module based on Rothermel's fire equation does
such work. The combination of the two forms a simulation of wildfire
spread.

3\. The relationship of the start map and ROS maps should be logically
correct, i.e. a starting source (a positive value in the start map)
should not be located in a spread *barrier* (zero value in the ROS
maps). Otherwise the program refuses to run.

4\. *r.spread* uses the current computational region settings. The
output map layer will not go outside the boundaries set in the region,
and will not be influenced by starting sources outside. So any change of
the current region may influence the output. The recommendation is to
use slightly larger region than needed. Refer to
*[g.region](g.region.md)* to set an appropriate computational region.

5\. The user should be sure that the inputs to *r.spread* are in proper
units.

6\. *r.spread* is a computationally intensive program. The user may need
to choose appropriate size of the computational region and resolution.

7\. A low and medium (i.e. \<= 0.5) sampling density can improve
accuracy for elliptical simulation significantly, without adding
significantly extra running time. Further increasing the sample density
will not gain much accuracy while requiring greatly additional running
time.

## REFERENCES

- Chase, Carolyn, H., 1984, Spotting distance from wind-driven surface
  fires -- extensions of equations for pocket calculators, US Forest
  Service, Res. Note INT-346, Ogden, Utah.
- Rothermel, R. C., 1983, How to predict the spread and intensity of
  forest and range fires. US Forest Service, Gen. Tech. Rep. INT-143.
  Ogden, Utah.
- Xu, Jianping, 1994, Simulating the spread of wildfires using a
  geographic information system and remote sensing, Ph. D. Dissertation,
  Rutgers University, New Brunswick, New Jersey
  ([ref](https://dl.acm.org/citation.cfm?id=921466)).

## SEE ALSO

*[r.cost](r.cost.md), [r.mask](r.mask.md), [r.ros](r.ros.md),
[r.spreadpath](r.spreadpath.md)* Sample data download:
[firedemo.sh](https://grass.osgeo.org/sampledata/firedemo_grass7.sh)
(run this script within the "Fire simulation data set" project).

## AUTHORS

Jianping Xu and Richard G. Lathrop, Jr., Center for Remote Sensing and
Spatial Analysis, Rutgers University.
